import {Component, OnInit} from '@angular/core';
import {NzMessageService} from 'ng-zorro-antd';
import {ModalHelper} from '@delon/theme';
import {HttpClient} from '@angular/common/http';
import * as moment from 'moment';
import {environment} from '../../../../environments/environment';
import {DateService} from '../../../core/services/date.service';
import { AlarmUserEditComponent } from './alarm-user-edit/alarm-user-edit.component';

@Component({
  selector: 'app-alarm-user',
  templateUrl: './alarm-user.component.html',
  styles: []
})
export class AlarmUserComponent implements OnInit {

  options = [
    {value: '1', label: '是'},
    {value: '0', label: '否'}
  ];

  query: any = {
    pageIndex: 1,
    pageSize: 10,
    isDelete: this.options[1].value
  };
  data: any[] = [];
  total: 0;

  selectedRows: any[] = [];
  allChecked = false;
  indeterminate = false;
  sortMap: any = {};

  constructor(
    public http: HttpClient,
    public dateSrv: DateService,
    public msgSrv: NzMessageService,
    private modalHelper: ModalHelper) {

  }

  load(reload: boolean = false) {
   if (reload) {
      this.query.pageIndex = 1;
    }
    this.http.get(environment.SERVER_BASH_URL + '/alarmUser/list', {params: this.query}).subscribe((res: any) => {
      this.data = res.data.data;
      this.total = res.data.total;

      this.refreshStatus();
    });
  }

  ngOnInit() {
    this.load();
  }

  edit(alarmUser) {
    this.modalHelper.static(AlarmUserEditComponent, {alarmUser}).subscribe(() => {
      this.load(true);
      this.msgSrv.success('账户修改成功！');
    });
  }

  add() {
    const alarmUser = {};
    this.modalHelper.static(AlarmUserEditComponent, {alarmUser}).subscribe(() => {
      this.load(true);
      this.msgSrv.success('账户保存成功！');
    });
  }

  delete(alarmUser) {
    this.http.post(environment.SERVER_BASH_URL + '/alarmUser/alarmUser/id' , alarmUser).subscribe((res: any) => {
      if(res.data > 0){
        this.msgSrv.success('账户删除成功！');
        this.load(true);
      } else {
        this.msgSrv.error(res.message);
      }
    });
  }

  remove() {
    const ids = [];
    this.selectedRows.forEach(i => {
      ids.push(i.id);
    });
    this.http.post(environment.SERVER_BASH_URL + '/alarmUser/alarmUsers/ids', ids).subscribe((res: any) => {
      this.load(true);
    });
  }

  checkAll(value: boolean) {
    this.data.forEach(i => {
      if (i.isDelete == '1') {
        i.checked = false;
      } else {
        i.checked = value;
      }
    });
    this.refreshStatus();
  }

  refreshStatus() {
    const allChecked = this.data.every(value => value.checked);
    const allUnChecked = this.data.every(value => !value.checked);
    this.allChecked = allChecked;
    this.indeterminate = (!allChecked) && (!allUnChecked);
    this.selectedRows = this.data.filter(value => value.checked);
  }

  sort(field: string, value: any) {
    this.sortMap = {};
    this.sortMap[field] = value;
    this.query.sorter = value ? `${field} ${value}` : '';
    this.load(true);
  }

  format_date(date) {
    return this.dateSrv.date_format(date, 'YYYY-MM-DD');
  }

}
